@@ -8,7 +8,7 @@ if os.path.isdir(DIR):
 
 import unittest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view
+from trytond.tests.test_tryton import test_view, test_depends
 
 
 class HealthGynecoTestCase(unittest.TestCase):
@@ -25,6 +25,12 @@ class HealthGynecoTestCase(unittest.TestCase):
         '''
         test_view('health_gyneco')
 
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
 def suite():
     suite = trytond.tests.test_tryton.suite()
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
