@@ -95,19 +95,13 @@ class RequestPatientImagingTestStart(ModelView):
 
     @staticmethod
     def default_doctor():
-        cursor = Transaction().cursor
-        User = Pool().get('res.user')
-        user = User(Transaction().user)
-        login_user_id = int(user.id)
-        cursor.execute('SELECT id FROM party_party WHERE is_healthprof=True AND'
-            ' internal_user = %s LIMIT 1', (login_user_id,))
-        partner_id = cursor.fetchone()
-        if partner_id:
-            cursor = Transaction().cursor
-            cursor.execute('SELECT id FROM gnuhealth_healthprofessional WHERE '
-                'name = %s LIMIT 1', (partner_id[0],))
-            doctor_id = cursor.fetchone()
-            return int(doctor_id[0])
+        pool = Pool()
+        HealthProf= pool.get('gnuhealth.healthprofessional')
+        hp = HealthProf.get_health_professional()
+        if not hp:
+            RequestPatientImagingTestStart.raise_user_error(
+                "No health professional associated to this user !")
+        return hp
 
 
 class RequestPatientImagingTest(Wizard):
