@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2013  Sebastian Marro <smarro@gnusolidario.org>
+#    Copyright (C) 2011-2014 Sebastian Marro <smarro@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -27,22 +27,12 @@ def register():
     Pool.register(
         TopDiseases,
         OpenTopDiseasesStart,
+        OpenEvaluationsStart,
         EvaluationsDoctor,
-        OpenEvaluationsDoctorStart,
-        EvaluationsDoctorWeekly,
-        EvaluationsDoctorMonthly,
         EvaluationsSpecialty,
-        OpenEvaluationsSpecialtyStart,
-        EvaluationsSpecialtyWeekly,
-        EvaluationsSpecialtyMonthly,
         EvaluationsSector,
-        OpenEvaluationsSectorStart,
-        EvaluationsSectorWeekly,
-        EvaluationsSectorMonthly,
         module='health_reporting', type_='model')
     Pool.register(
         OpenTopDiseases,
-        OpenEvaluationsDoctor,
-        OpenEvaluationsSpecialty,
-        OpenEvaluationsSector,
+        OpenEvaluations,
         module='health_reporting', type_='wizard')
